@@ -1,10 +1,22 @@
-import React from 'react'
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+
+import { useEffect } from 'react'
 import { Switch, Route, Link, useLocation, useHistory } from 'react-router-dom'
 import _ from 'lodash'
-import { AcmButton, AcmPage, AcmPageHeader, AcmSecondaryNav, AcmSecondaryNavItem } from '@stolostron/ui-components'
+import {
+    AcmButton,
+    AcmPage,
+    AcmPageHeader,
+    AcmRoute,
+    AcmSecondaryNav,
+    AcmSecondaryNavItem,
+} from '@open-cluster-management/ui-components'
 import '@patternfly/react-core/dist/styles/base.css'
 import { makeStyles } from '@material-ui/styles'
 import { useTranslation } from 'react-i18next'
+import { useRecoilState } from 'recoil'
+import { acmRouteState } from '../../util'
 import YAMLPage from './YAMLPage'
 import LogsPage from './LogsPage'
 import { consoleClient } from '../../console-sdk/console-client'
@@ -51,6 +63,8 @@ function getResourceData() {
 
 export default function DetailsPage() {
     const { t } = useTranslation(['details'])
+    const [, setRoute] = useRecoilState(acmRouteState)
+    useEffect(() => setRoute(AcmRoute.Resources), [setRoute])
     const { cluster, kind, apiversion, namespace, name } = getResourceData()
     let resourceUrlParams = ''
     resourceUrlParams = `${resourceUrlParams}${cluster !== '' ? `cluster=${cluster}` : ''}`
@@ -73,43 +87,48 @@ export default function DetailsPage() {
     const history = useHistory()
 
     return (
-        <AcmPage>
-            <div className={classes.customBreadcrumb}>
-                <AcmButton
-                    variant={'link'}
-                    onClick={() => {
-                        const prevLocState = window.history?.state?.state
-                        if (prevLocState && prevLocState.from === '/search') {
-                            // If we came to resources page from search - return to search with previous search filters
-                            history.goBack()
-                        } else {
-                            // If we were redirected to search from elsewhere (ex: application page) - go to blank search page
-                            window.location.href = '/search'
+        <AcmPage
+            header={
+                <div>
+                    <div className={classes.customBreadcrumb}>
+                        <AcmButton
+                            variant={'link'}
+                            onClick={() => {
+                                const prevLocState = window.history?.state?.state
+                                if (prevLocState && prevLocState.from === '/search') {
+                                    // If we came to resources page from search - return to search with previous search filters
+                                    history.goBack()
+                                } else {
+                                    // If we were redirected to search from elsewhere (ex: application page) - go to blank search page
+                                    window.location.href = '/search'
+                                }
+                            }}
+                        >
+                            {t('details.breadcrumb.search')}
+                        </AcmButton>
+                    </div>
+                    <AcmPageHeader
+                        title={name}
+                        navigation={
+                            <AcmSecondaryNav>
+                                <AcmSecondaryNavItem isActive={location.pathname === '/resources'}>
+                                    <Link replace to={`/resources?${encodeURIComponent(resourceUrlParams)}`}>
+                                        YAML
+                                    </Link>
+                                </AcmSecondaryNavItem>
+                                {(kind.toLowerCase() === 'pod' || kind.toLowerCase() === 'pods') && (
+                                    <AcmSecondaryNavItem isActive={location.pathname === '/resources/logs'}>
+                                        <Link replace to={`/resources/logs?${encodeURIComponent(resourceUrlParams)}`}>
+                                            Logs
+                                        </Link>
+                                    </AcmSecondaryNavItem>
+                                )}
+                            </AcmSecondaryNav>
                         }
-                    }}
-                >
-                    {t('details.breadcrumb.search')}
-                </AcmButton>
-            </div>
-            <AcmPageHeader
-                title={name}
-                navigation={
-                    <AcmSecondaryNav>
-                        <AcmSecondaryNavItem isActive={location.pathname === '/resources'}>
-                            <Link replace to={`/resources?${encodeURIComponent(resourceUrlParams)}`}>
-                                YAML
-                            </Link>
-                        </AcmSecondaryNavItem>
-                        {(kind.toLowerCase() === 'pod' || kind.toLowerCase() === 'pods') && (
-                            <AcmSecondaryNavItem isActive={location.pathname === '/resources/logs'}>
-                                <Link replace to={`/resources/logs?${encodeURIComponent(resourceUrlParams)}`}>
-                                    Logs
-                                </Link>
-                            </AcmSecondaryNavItem>
-                        )}
-                    </AcmSecondaryNav>
-                }
-            />
+                    />
+                </div>
+            }
+        >
             <Switch>
                 <Route exact path={'/resources'}>
                     <YAMLPage
@@ -126,6 +145,8 @@ export default function DetailsPage() {
                 {(kind.toLowerCase() === 'pod' || kind.toLowerCase() === 'pods') && (
                     <Route path={'/resources/logs'}>
                         <LogsPage
+                            getResource={getResourceResponse.data}
+                            getResourceError={getResourceResponse.error}
                             containers={_.get(getResourceResponse, 'data.getResource.spec.containers', []).map(
                                 (container: any) => container.name
                             )}
