@@ -1,6 +1,8 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import { useState, useEffect } from 'react'
 import { PageSection } from '@patternfly/react-core'
-import { AcmAlert, AcmButton, AcmLoadingPage } from '@stolostron/ui-components'
+import { AcmAlert, AcmButton, AcmLoadingPage } from '@open-cluster-management/ui-components'
 import { ApolloError } from '@apollo/client'
 import { makeStyles } from '@material-ui/styles'
 import jsYaml from 'js-yaml'
@@ -98,7 +100,11 @@ export default function YAMLPage(props: {
     // Need to split the apigroup & apiversion (ex: for deployments = apps/v1)
     const apiGroup = apiversion.includes('/') ? apiversion.split('/')[0] : ''
     const version = apiversion.includes('/') ? apiversion.split('/')[1] : apiversion.split('/')[0]
-    const { data: userAccessData, loading: userAccessLoading, error: userAccessError } = useUserAccessQuery({
+    const {
+        data: userAccessData,
+        loading: userAccessLoading,
+        error: userAccessError,
+    } = useUserAccessQuery({
         client: consoleClient,
         variables: {
             kind,
@@ -121,7 +127,21 @@ export default function YAMLPage(props: {
                     variant={'danger'}
                     isInline={true}
                     title={`${t('yaml.getresource.error')} ${name}`}
-                    subtitle={error.message}
+                    subtitle={error?.message}
+                />
+            </PageSection>
+        )
+    } else if (resource?.getResource?.message ?? (resource?.getResource[0] && resource?.getResource[0].message)) {
+        return (
+            <PageSection>
+                <AcmAlert
+                    noClose={true}
+                    variant={'danger'}
+                    isInline={true}
+                    title={`${t('yaml.getresource.error')} ${name}`}
+                    subtitle={
+                        resource?.getResource?.message ?? (resource?.getResource[0] && resource?.getResource[0].message)
+                    }
                 />
             </PageSection>
         )
@@ -214,7 +234,6 @@ export default function YAMLPage(props: {
                     fontSize: 12,
                     wordWrap: 'wordWrapColumn',
                     wordWrapColumn: 132,
-                    wordWrapMinified: false,
                     scrollBeyondLastLine: false,
                     smoothScrolling: true,
                     glyphMargin: true,
