@@ -1,4 +1,6 @@
-import React, { Dispatch, Fragment, SetStateAction, useEffect, useState } from 'react'
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+import { Dispatch, Fragment, SetStateAction, useEffect, useState } from 'react'
 import {
     AcmAlert,
     AcmChartGroup,
@@ -15,13 +17,16 @@ import {
     AcmLaunchLink,
     AcmAutoRefreshSelect,
     AcmRefreshTime,
-} from '@stolostron/ui-components'
+    AcmRoute,
+} from '@open-cluster-management/ui-components'
 import { ButtonVariant, PageSection } from '@patternfly/react-core'
 import { PlusIcon } from '@patternfly/react-icons'
 import { useTranslation } from 'react-i18next'
+import { useRecoilState } from 'recoil'
+import { acmRouteState } from '../../util'
 import { consoleClient } from '../../console-sdk/console-client'
 import { useGetOverviewLazyQuery, useGetResourceQuery } from '../../console-sdk/console-sdk'
-import { useSearchResultCountLazyQuery } from '../../search-sdk/search-sdk'
+import { useSearchResultCountLazyQuery, useSearchResultItemsLazyQuery } from '../../search-sdk/search-sdk'
 import { searchClient } from '../../search-sdk/search-client'
 import { ClusterManagementAddOn } from '../../lib/resource-request'
 import _ from 'lodash'
@@ -38,10 +43,16 @@ export function mapProviderFromLabel(provider: string): Provider {
             return Provider.gcp
         case 'IBM':
             return Provider.ibm
+        case 'IBMPowerPlatform':
+            return Provider.ibmpower
+        case 'IBMZPlatform':
+            return Provider.ibmz
         case 'RedHat':
             return Provider.redhatcloud
         case 'VMware':
             return Provider.vmware
+        case 'OpenStack':
+            return Provider.openstack
         default:
             return Provider.other
     }
@@ -140,32 +151,31 @@ const PageActions = (props: { timestamp: string; reloading: boolean; refetch: ()
     const { data, error } = useGetResourceQuery({
         client: consoleClient,
         variables: {
-            selfLink: '/apis/addon.open-cluster-management.io/v1alpha1/clustermanagementaddons',
             namespace: 'open-cluster-management',
-            name: null,
+            name: 'observability-controller',
             cluster: 'local-cluster',
-            kind: null,
+            kind: 'clustermanagementaddon',
+            apiVersion: 'addon.open-cluster-management.io/v1alpha1',
         },
     })
     if (error) {
         // TODO: Better error handling
         console.error(error)
     }
-    const addons = data?.getResource.items
-
-    function getLaunchLink(addons: ClusterManagementAddOn[]) {
+    const addons = data?.getResource
+    function getLaunchLink(addon: ClusterManagementAddOn) {
         const pathKey = 'console.open-cluster-management.io/launch-link'
         const textKey = 'console.open-cluster-management.io/launch-link-text'
-        if (addons && addons.filter((addon) => addon.metadata.name === 'observability-controller')) {
-            return addons
-                ?.filter((addon) => addon.metadata.name === 'observability-controller')
-                ?.map((addon) => ({
-                    id: addon.metadata.annotations![textKey] ?? '',
-                    text: addon.metadata.annotations![textKey] ?? '',
-                    href: addon.metadata.annotations![pathKey] ?? '',
-                }))
+        if (addon && addon.metadata.name === 'observability-controller') {
+            return [
+                {
+                    id: addon.metadata.annotations?.[textKey] || '',
+                    text: addon.metadata.annotations?.[textKey] || '',
+                    href: addon.metadata.annotations?.[pathKey] || '',
+                },
+            ]
         } else {
-            return undefined
+            return []
         }
     }
 
@@ -174,7 +184,7 @@ const PageActions = (props: { timestamp: string; reloading: boolean; refetch: ()
             <AcmActionGroup>
                 <AcmLaunchLink links={getLaunchLink(addons)} />
                 <AcmButton
-                    href="/multicloud/add-connection"
+                    href="/multicloud/credentials"
                     variant={ButtonVariant.link}
                     component="a"
                     rel="noreferrer"
@@ -193,6 +203,8 @@ const PageActions = (props: { timestamp: string; reloading: boolean; refetch: ()
 
 export default function OverviewPage() {
     const { t } = useTranslation(['overview'])
+    const [, setRoute] = useRecoilState(acmRouteState)
+    useEffect(() => setRoute(AcmRoute.Overview), [setRoute])
     const [clusters, setClusters] = useState<any[]>([])
     const [selectedCloud, setSelectedCloud] = useState<string>('')
     const [selectedClusterNames, setSelectedClusterNames] = useState<string[]>([])
@@ -275,9 +287,84 @@ export default function OverviewPage() {
         }
     }, [clusters, selectedCloud, data, searchData, selectedClusterNames])
 
+    const [
+        firePolicyReportQuery,
+        {
+            called: searchPolicyReportCalled,
+            data: searchPolicyReportData,
+            loading: searchPolicyReportLoading,
+            error: searchPolicyReportError,
+            refetch: searchPolicyReportRefetch,
+        },
+    ] = useSearchResultItemsLazyQuery({
+        client: process.env.NODE_ENV === 'test' ? undefined : searchClient,
+    })
+
+    const policyReportQuery = (clustersToSearch: Array<string>) => {
+        return [
+            {
+                keywords: [],
+                filters: [
+                    {
+                        property: 'kind',
+                        values: ['policyreport'],
+                    },
+                    {
+                        property: 'scope',
+                        values: clustersToSearch,
+                    },
+                ],
+            },
+        ]
+    }
+
+    useEffect(() => {
+        const clustersToSearch =
+            selectedClusterNames.length > 0 ? selectedClusterNames : clusters.map((cluster) => cluster.metadata.name)
+        if (!searchPolicyReportCalled && clustersToSearch.length > 0) {
+            // The console call needs to finish first.
+            firePolicyReportQuery({
+                variables: { input: policyReportQuery(clustersToSearch) },
+            })
+        } else if (clustersToSearch.length > 0) {
+            searchPolicyReportRefetch &&
+                searchPolicyReportRefetch({
+                    input: policyReportQuery(clustersToSearch),
+                })
+        }
+    }, [
+        firePolicyReportQuery,
+        called,
+        clusters,
+        selectedClusterNames,
+        searchPolicyReportCalled,
+        searchPolicyReportRefetch,
+    ])
+    const searchPolicyReportResult = searchPolicyReportData?.searchResult || []
+    const policyReportItems = searchPolicyReportResult[0]?.items || []
+    const policyReportCriticalCount = policyReportItems.reduce(
+        (total: any, currentValue: any) => total + currentValue.critical,
+        0
+    )
+    const policyReportImportantCount = policyReportItems.reduce(
+        (total: any, currentValue: any) => total + currentValue.important,
+        0
+    )
+    const policyReportModerateCount = policyReportItems.reduce(
+        (total: any, currentValue: any) => total + currentValue.moderate,
+        0
+    )
+    const policyReportLowCount = policyReportItems.reduce(
+        (total: any, currentValue: any) => total + currentValue.low,
+        0
+    )
+
     const refetchData = () => {
         refetch && refetch()
         searchRefetch && searchRefetch({ input: searchQueries(selectedClusterNames) })
+        const clustersToSearch =
+            selectedClusterNames.length > 0 ? selectedClusterNames : clusters.map((cluster) => cluster.metadata.name)
+        searchPolicyReportRefetch && searchPolicyReportRefetch({ input: policyReportQuery(clustersToSearch) })
     }
 
     const { kubernetesTypes, regions, ready, offline, providers } = summaryData
@@ -289,7 +376,7 @@ export default function OverviewPage() {
             : `/search?filters={"textsearch":"kind%3Acluster${cloudLabelFilter}"}&showrelated=${kind}`
     }
     const summary =
-        loading || searchLoading
+        loading || searchLoading || searchPolicyReportLoading
             ? []
             : [
                   {
@@ -324,18 +411,17 @@ export default function OverviewPage() {
               ]
 
     // TODO: Breaks url if length of selectedClustersFilter is too big.
-    // Issue: https://github.com/stolostron/backlog/issues/7087
+    // Issue: https://github.com/open-cluster-management/backlog/issues/7087
     const urlClusterFilter: string =
         selectedClusterNames.length > 0 ? `%20cluster%3A${selectedClusterNames.join(',')}` : ''
     const podData =
-        loading || searchLoading
+        loading || searchLoading || searchPolicyReportLoading
             ? []
             : [
                   {
-                      key: 'Running',
-                      value: searchResult[2]?.count || 0,
-                      isPrimary: true,
-                      link: `/search?filters={"textsearch":"kind%3Apod%20status%3ARunning%2CCompleted${urlClusterFilter}"}`,
+                      key: 'Failed',
+                      value: searchResult[4]?.count || 0,
+                      link: `/search?filters={"textsearch":"kind%3Apod%20status%3ACrashLoopBackOff%2CFailed%2CImagePullBackOff%2CRunContainerError%2CTerminated%2CUnknown%2COOMKilled${urlClusterFilter}"}`,
                   },
                   {
                       key: 'Pending',
@@ -343,70 +429,114 @@ export default function OverviewPage() {
                       link: `/search?filters={"textsearch":"kind%3Apod%20status%3AContainerCreating%2CPending%2CTerminating%2CWaiting${urlClusterFilter}"}`,
                   },
                   {
-                      key: 'Failed',
-                      value: searchResult[4]?.count || 0,
-                      isDanger: true,
-                      link: `/search?filters={"textsearch":"kind%3Apod%20status%3ACrashLoopBackOff%2CFailed%2CImagePullBackOff%2CRunContainerError%2CTerminated%2CUnknown%2COOMKilled${urlClusterFilter}"}`,
+                      key: 'Running',
+                      value: searchResult[2]?.count || 0,
+                      isPrimary: true,
+                      link: `/search?filters={"textsearch":"kind%3Apod%20status%3ARunning%2CCompleted${urlClusterFilter}"}`,
                   },
               ]
 
     // TODO: Breaks url if length of selectedClustersFilter is too big.
-    // Issue: https://github.com/stolostron/backlog/issues/7087
+    // Issue: https://github.com/open-cluster-management/backlog/issues/7087
     function buildClusterComplianceLinks(clusterNames: Array<string> = []): string {
         return `/search?filters={"textsearch":"kind:cluster${
             clusterNames.length > 0 ? `%20name:${clusterNames.join(',')}` : ''
         }"}&showrelated=policy`
     }
     const complianceData =
-        loading || searchLoading
+        loading || searchLoading || searchPolicyReportLoading
             ? []
             : [
+                  {
+                      key: 'Non-compliant',
+                      value: nonCompliantClusters.size,
+                      link: buildClusterComplianceLinks(Array.from(nonCompliantClusters)),
+                  },
                   {
                       key: 'Compliant',
                       value: compliantClusters.length,
                       isPrimary: true,
                       link: buildClusterComplianceLinks(compliantClusters),
                   },
-                  {
-                      key: 'Non-compliant',
-                      value: nonCompliantClusters.size,
-                      isDanger: true,
-                      link: buildClusterComplianceLinks(Array.from(nonCompliantClusters)),
-                  },
               ]
 
     const clusterData =
-        loading || searchLoading
+        loading || searchLoading || searchPolicyReportLoading
             ? []
             : [
+                  {
+                      key: 'Offline',
+                      value: offline,
+                      link: `/search?filters={"textsearch":"kind%3Acluster%20ManagedClusterConditionAvailable%3A!True${cloudLabelFilter}"}`,
+                  },
                   {
                       key: 'Ready',
                       value: ready,
                       isPrimary: true,
                       link: `/search?filters={"textsearch":"kind%3Acluster%20ManagedClusterConditionAvailable%3ATrue${cloudLabelFilter}"}`,
                   },
+              ]
+
+    const policyReportData =
+        loading || searchLoading || searchPolicyReportLoading
+            ? []
+            : [
                   {
-                      key: 'Offline',
-                      value: offline,
-                      isDanger: true,
-                      link: `/search?filters={"textsearch":"kind%3Acluster%20ManagedClusterConditionAvailable%3A!True${cloudLabelFilter}"}`,
+                      key: 'Critical',
+                      value: policyReportCriticalCount,
+                      isPrimary: true,
+                      link:
+                          policyReportCriticalCount > 0
+                              ? `/search?filters={"textsearch":"kind%3Apolicyreport%20critical%3A>0"}`
+                              : undefined,
+                  },
+                  {
+                      key: 'Important',
+                      value: policyReportImportantCount,
+                      link:
+                          policyReportImportantCount > 0
+                              ? `/search?filters={"textsearch":"kind%3Apolicyreport%20important%3A>0"}`
+                              : undefined,
+                  },
+                  {
+                      key: 'Moderate',
+                      value: policyReportModerateCount,
+                      link:
+                          policyReportModerateCount > 0
+                              ? `/search?filters={"textsearch":"kind%3Apolicyreport%20moderate%3A>0"}`
+                              : undefined,
+                  },
+                  {
+                      key: 'Low',
+                      value: policyReportLowCount,
+                      link:
+                          policyReportLowCount > 0
+                              ? `/search?filters={"textsearch":"kind%3Apolicyreport%20low%3A>0"}`
+                              : undefined,
                   },
               ]
 
-    if (error || searchError) {
+    if (error || searchError || searchPolicyReportError) {
         return (
-            <AcmPage>
-                <AcmPageHeader
-                    title={t('overview')}
-                    actions={<PageActions timestamp={timestamp} reloading={loading} refetch={refetchData} />}
-                />
+            <AcmPage
+                header={
+                    <AcmPageHeader
+                        title={t('overview')}
+                        actions={<PageActions timestamp={timestamp} reloading={loading} refetch={refetchData} />}
+                    />
+                }
+            >
                 <PageSection>
                     <AcmAlert
                         noClose
                         isInline
-                        variant={'danger'}
-                        title={t('overview.data.error.title')}
-                        subtitle={t('overview.data.error.message')}
+                        variant={searchError?.graphQLErrors[0]?.message.includes('not enabled') ? 'info' : 'danger'}
+                        title={
+                            searchError?.graphQLErrors[0]?.message.includes('not enabled')
+                                ? t('overview.data.info.title')
+                                : t('overview.data.error.title')
+                        }
+                        subtitle={searchError?.graphQLErrors[0]?.message || t('overview.data.error.message')}
                     />
                 </PageSection>
             </AcmPage>
@@ -414,15 +544,18 @@ export default function OverviewPage() {
     }
 
     return (
-        <AcmPage>
-            <AcmPageHeader
-                title={t('overview')}
-                actions={
-                    <PageActions timestamp={timestamp} reloading={loading || searchLoading} refetch={refetchData} />
-                }
-            />
+        <AcmPage
+            header={
+                <AcmPageHeader
+                    title={t('overview')}
+                    actions={
+                        <PageActions timestamp={timestamp} reloading={loading || searchLoading} refetch={refetchData} />
+                    }
+                />
+            }
+        >
             <AcmScrollable>
-                {!called || loading || searchLoading ? (
+                {!called || loading || searchLoading || searchPolicyReportLoading ? (
                     <AcmLoadingPage />
                 ) : (
                     <PageSection>
@@ -431,7 +564,7 @@ export default function OverviewPage() {
                 )}
 
                 <PageSection>
-                    {!called || loading || searchLoading ? (
+                    {!called || loading || searchLoading || searchPolicyReportLoading ? (
                         <AcmSummaryList key="loading" loading title={t('overview.summary.title')} list={summary} />
                     ) : (
                         <AcmSummaryList title={t('overview.summary.title')} list={summary} />
@@ -439,7 +572,7 @@ export default function OverviewPage() {
                 </PageSection>
 
                 <PageSection>
-                    {!called || loading || searchLoading ? (
+                    {!called || loading || searchLoading || searchPolicyReportLoading ? (
                         <AcmChartGroup>
                             <AcmDonutChart
                                 loading
@@ -464,6 +597,13 @@ export default function OverviewPage() {
                                 description={t('overview.donut.status.description', { cluster: 'cluster' })}
                                 data={[]}
                             />
+                            <AcmDonutChart
+                                loading
+                                key="chart-loading-4"
+                                title="Clusters with issues"
+                                description={t('overview.donut.policyreport.description')}
+                                data={[]}
+                            />
                         </AcmChartGroup>
                     ) : (
                         <AcmChartGroup>
@@ -473,16 +613,29 @@ export default function OverviewPage() {
                                     compliance: 'policy compliance',
                                 })}
                                 data={complianceData}
+                                colorScale={['#E62326', '#0066CC']}
                             />
                             <AcmDonutChart
                                 title="Pods"
                                 description={t('overview.donut.pod.description', { pod: 'pod' })}
                                 data={podData}
+                                colorScale={['#E62326', '#8BC1F7', '#0066CC']}
                             />
                             <AcmDonutChart
                                 title="Cluster status"
                                 description={t('overview.donut.status.description', { cluster: 'cluster' })}
                                 data={clusterData}
+                                colorScale={['#E62326', '#0066CC']}
+                            />
+                            <AcmDonutChart
+                                title="Cluster issues"
+                                description={t('overview.donut.policyreport.description')}
+                                data={policyReportData}
+                                donutLabel={{
+                                    title: `${policyReportItems.length}`,
+                                    subTitle: t('overview.donut.policyreport.pie.label'),
+                                }}
+                                colorScale={['#E62325', '#EC7A08', '#F4C145', '#2B9AF3', '#72767B']}
                             />
                         </AcmChartGroup>
                     )}
