@@ -1,7 +1,16 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import '@patternfly/react-core/dist/styles/base.css'
 import React, { Fragment, useReducer, useEffect, useState } from 'react'
 import { ButtonVariant, ModalVariant } from '@patternfly/react-core'
-import { AcmModal, AcmButton, AcmForm, AcmTextInput, AcmTextArea, AcmAlert } from '@stolostron/ui-components'
+import {
+    AcmModal,
+    AcmButton,
+    AcmForm,
+    AcmTextInput,
+    AcmTextArea,
+    AcmAlert,
+} from '@open-cluster-management/ui-components'
 import { useTranslation } from 'react-i18next'
 import { SavedSearchesDocument, useSaveSearchMutation } from '../../../../search-sdk/search-sdk'
 import { searchClient } from '../../../../search-sdk/search-client'
@@ -125,6 +134,8 @@ export const SaveAndEditSearchModal = (props: any) => {
                         value={searchName}
                         onChange={onChange}
                         maxLength={50}
+                        placeholder={t('search.modal.save.input.name.placeholder')}
+                        isRequired={true}
                     />
                     <AcmTextArea
                         id="add-query-desc"
@@ -134,6 +145,7 @@ export const SaveAndEditSearchModal = (props: any) => {
                         onChange={onChange}
                         required
                         maxLength={120}
+                        placeholder={t('search.modal.save.input.description.placeholder')}
                     />
                 </AcmForm>
             </AcmModal>
