@@ -1,8 +1,9 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import '@patternfly/react-core/dist/styles/base.css'
 import React, { Fragment } from 'react'
-import { AcmButton, AcmLabels, AcmModal } from '@stolostron/ui-components'
+import { AcmLabels, AcmModal } from '@open-cluster-management/ui-components'
 import { makeStyles } from '@material-ui/styles'
-import { ButtonVariant } from '@patternfly/react-core'
 import { useTranslation } from 'react-i18next'
 
 const useStyles = makeStyles({
@@ -52,11 +53,6 @@ export const SearchInfoModal = (props: any) => {
                 width={'50%'}
                 onClose={props.onClose}
                 isOpen={props.isOpen}
-                actions={[
-                    <AcmButton key="close" variant={ButtonVariant.primary} onClick={props.onClose}>
-                        {t('search.modal.info.action.cancel')}
-                    </AcmButton>,
-                ]}
             >
                 <div>
                     <h2>{t('search.modal.info.subtitle')}</h2>
