@@ -34,6 +34,10 @@ export const ToggleSearchScopeKeybinding = {
     primary: 512 /* Alt */ | 42 /* KEY_L */,
     mac: { primary: 2048 /* CtrlCmd */ | 512 /* Alt */ | 42 /* KEY_L */ }
 };
+export const TogglePreserveCaseKeybinding = {
+    primary: 512 /* Alt */ | 46 /* KEY_P */,
+    mac: { primary: 2048 /* CtrlCmd */ | 512 /* Alt */ | 46 /* KEY_P */ }
+};
 export const FIND_IDS = {
     StartFindAction: 'actions.find',
     StartFindWithSelection: 'actions.findWithSelection',
@@ -169,7 +173,7 @@ export class FindModelBoundToEditorModel {
             currentMatchesPosition = matchAfterSelection > 0 ? matchAfterSelection - 1 + 1 /** match position is one based */ : currentMatchesPosition;
         }
         this._state.changeMatchInfo(currentMatchesPosition, this._decorations.getCount(), undefined);
-        if (moveCursor && this._editor.getOption(29 /* find */).cursorMoveOnType) {
+        if (moveCursor && this._editor.getOption(33 /* find */).cursorMoveOnType) {
             this._moveToNextMatch(this._decorations.getStartPosition());
         }
     }
@@ -249,11 +253,11 @@ export class FindModelBoundToEditorModel {
         let { lineNumber, column } = before;
         let model = this._editor.getModel();
         let position = new Position(lineNumber, column);
-        let prevMatch = model.findPreviousMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null, false);
+        let prevMatch = model.findPreviousMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null, false);
         if (prevMatch && prevMatch.range.isEmpty() && prevMatch.range.getStartPosition().equals(position)) {
             // Looks like we're stuck at this position, unacceptable!
             position = this._prevSearchPosition(position);
-            prevMatch = model.findPreviousMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null, false);
+            prevMatch = model.findPreviousMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null, false);
         }
         if (!prevMatch) {
             // there is precisely one match and selection is on top of it
@@ -330,11 +334,11 @@ export class FindModelBoundToEditorModel {
         let { lineNumber, column } = after;
         let model = this._editor.getModel();
         let position = new Position(lineNumber, column);
-        let nextMatch = model.findNextMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null, captureMatches);
+        let nextMatch = model.findNextMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null, captureMatches);
         if (forceMove && nextMatch && nextMatch.range.isEmpty() && nextMatch.range.getStartPosition().equals(position)) {
             // Looks like we're stuck at this position, unacceptable!
             position = this._nextSearchPosition(position);
-            nextMatch = model.findNextMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null, captureMatches);
+            nextMatch = model.findNextMatch(this._state.searchString, position, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null, captureMatches);
         }
         if (!nextMatch) {
             // there is precisely one match and selection is on top of it
@@ -378,7 +382,7 @@ export class FindModelBoundToEditorModel {
     }
     _findMatches(findScopes, captureMatches, limitResultCount) {
         const searchRanges = (findScopes || [null]).map((scope) => FindModelBoundToEditorModel._getSearchRange(this._editor.getModel(), scope));
-        return this._editor.getModel().findMatches(this._state.searchString, searchRanges, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null, captureMatches, limitResultCount);
+        return this._editor.getModel().findMatches(this._state.searchString, searchRanges, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null, captureMatches, limitResultCount);
     }
     replaceAll() {
         if (!this._hasMatches()) {
@@ -395,7 +399,7 @@ export class FindModelBoundToEditorModel {
         this.research(false);
     }
     _largeReplaceAll() {
-        const searchParams = new SearchParams(this._state.searchString, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(105 /* wordSeparators */) : null);
+        const searchParams = new SearchParams(this._state.searchString, this._state.isRegex, this._state.matchCase, this._state.wholeWord ? this._editor.getOption(114 /* wordSeparators */) : null);
         const searchData = searchParams.parseSearchRequest();
         if (!searchData) {
             return;
