@@ -708,6 +708,7 @@ module.exports = {
 	"10.4.0": "85.0.4183.121",
 	"10.4.1": "85.0.4183.121",
 	"10.4.2": "85.0.4183.121",
+	"10.4.3": "85.0.4183.121",
 	"11.0.0-beta.1": "86.0.4234.0",
 	"11.0.0-beta.3": "86.0.4234.0",
 	"11.0.0-beta.4": "86.0.4234.0",
@@ -781,6 +782,7 @@ module.exports = {
 	"11.4.0": "87.0.4280.141",
 	"11.4.1": "87.0.4280.141",
 	"11.4.2": "87.0.4280.141",
+	"11.4.3": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -833,6 +835,9 @@ module.exports = {
 	"12.0.0": "89.0.4389.69",
 	"12.0.1": "89.0.4389.82",
 	"12.0.2": "89.0.4389.90",
+	"12.0.3": "89.0.4389.114",
+	"12.0.4": "89.0.4389.114",
+	"12.0.5": "89.0.4389.128",
 	"13.0.0-beta.2": "90.0.4402.0",
 	"13.0.0-beta.3": "90.0.4402.0",
 	"13.0.0-beta.4": "90.0.4415.0",
@@ -842,6 +847,11 @@ module.exports = {
 	"13.0.0-beta.8": "90.0.4415.0",
 	"13.0.0-beta.9": "90.0.4415.0",
 	"13.0.0-beta.11": "90.0.4415.0",
+	"13.0.0-beta.12": "90.0.4415.0",
+	"13.0.0-beta.13": "90.0.4415.0",
+	"13.0.0-beta.14": "91.0.4448.0",
+	"13.0.0-beta.16": "91.0.4448.0",
+	"13.0.0-beta.17": "91.0.4448.0",
 	"13.0.0-nightly.20201119": "89.0.4328.0",
 	"13.0.0-nightly.20201123": "89.0.4328.0",
 	"13.0.0-nightly.20201124": "89.0.4328.0",
@@ -912,5 +922,9 @@ module.exports = {
 	"14.0.0-nightly.20210331": "91.0.4448.0",
 	"14.0.0-nightly.20210401": "91.0.4448.0",
 	"14.0.0-nightly.20210402": "91.0.4448.0",
-	"14.0.0-nightly.20210406": "91.0.4448.0"
+	"14.0.0-nightly.20210406": "91.0.4448.0",
+	"14.0.0-nightly.20210407": "91.0.4448.0",
+	"14.0.0-nightly.20210408": "91.0.4448.0",
+	"14.0.0-nightly.20210409": "91.0.4448.0",
+	"14.0.0-nightly.20210413": "91.0.4448.0"
 };
\ No newline at end of file
